Module: ActiveSupport

Defined in:
lib/active_support/hash_with_indifferent_access.rb

Overview

This class has dubious semantics and we only have it so that people can write params[:key] instead of params['key'] and they get the same value for both keys.

Defined Under Namespace

Classes: HashWithIndifferentAccess